/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.policy;

import static org.fortiss.tooling.base.ui.utils.ZoomUIUtils.determineZoom;
import static org.fortiss.tooling.base.ui.utils.ZoomUIUtils.fixChangeBoundRequest;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.Request;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.UnexecutableCommand;
import org.eclipse.gef.editpolicies.NonResizableEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.editpart.StickyConnectorEditPartBase;
import org.fortiss.tooling.base.ui.editpart.command.MoveWithinElementCommand;
import org.fortiss.tooling.kernel.model.INamedCommentedElement;

/**
 * Layout policy for nodes in a diagram.
 * 
 * @author hoelzl
 */
public class ElementLayoutEditPolicy<T extends ILayoutedModelElement & INamedCommentedElement>
		extends RelayCreateCommandEditPolicyBase {

	/** The edit part. */
	private final ElementEditPartBase<T> part;

	/** Constructor */
	public ElementLayoutEditPolicy(ElementEditPartBase<T> part) {
		this.part = part;
	}

	/** {@inheritDoc} */
	@Override
	protected EditPolicy createChildEditPolicy(EditPart child) {
		if(child instanceof StickyConnectorEditPartBase) {
			// sticky connectors have a constraint area of movement
			return new StickyConnectorMoveEditPolicy<T>(part);
		}
		// free connectors may not be resized but moved freely
		return new NonResizableEditPolicy();
	}

	/** {@inheritDoc} */
	@Override
	protected Command getMoveChildrenCommand(Request request) {
		if(request instanceof ChangeBoundsRequest) {
			fixChangeBoundRequest((ChangeBoundsRequest)request, determineZoom(getHost().getRoot()));
			return new MoveWithinElementCommand((ChangeBoundsRequest)request);
		}
		return UnexecutableCommand.INSTANCE;
	}
}
