/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.databinding.validate;

import java.util.regex.Pattern;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;

import org.conqat.lib.commons.string.StringUtils;

/**
 * Validator for element name, i.e. string that are non-empty and consist of
 * alphanumeric characters , the underscore, or the hyphen.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: AF31025F26EC7681F4C746F3A78D12A1
 */
public class CleanNameValidator implements IValidator {

	/** Singleton instance. */
	public static final CleanNameValidator INSTANCE = new CleanNameValidator();

	/** Hidden constructor to enforce use of singleton instance. */
	private CleanNameValidator() {
		// nothing to do.
	}

	/**
	 * The pattern used to identify valid unit names. The most important part is
	 * to disallow dots and limit names to "sane" characters. We do not care
	 * about rules like for Java identifiers, where names may not start with
	 * numbers.
	 */
	public static final Pattern NAME_PATTERN = Pattern
			.compile("[-_a-zA-Z0-9]+");

	/** {@inheritDoc} */
	public IStatus validate(Object value) {
		if (!(value instanceof String)) {
			return ValidationStatus.error("Invalid input");
		}

		String name = (String) value;
		if (StringUtils.isEmpty(name)) {
			return ValidationStatus.error("Name may not be empty!");
		}

		if (!NAME_PATTERN.matcher(name).matches()) {
			return ValidationStatus
					.error("Invalid character in name: only alphanumerics, dash and underscore are allowed!");
		}

		return ValidationStatus.ok();
	}

}